@@ -1,19 +1,19 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
@@ -751,11 +751,16 @@ void apply_server_settings(struct w *widgets)
     	    strcat(new_conf, conf_line);
 	}
 	else
+    	if( strstr(line, "short preserve case") )
+	{
+	    /* Just remove the line */
+	}
+	else
     	if( strstr(line, "preserve case") )
 	{
 	    active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[14]));
 	    if( active_index == 0 )
-    	      sprintf(conf_line, "preserve case = yes\n");
+    	      sprintf(conf_line, "preserve case = yes\nshort preserve case = yes\n");
 	    else
     	      sprintf(conf_line, "preserve case = no\n");
 
@@ -1143,7 +1148,7 @@ void apply_server_settings(struct w *widgets)
     }
 
 
-//    fix_newlines_in_conf();
+    fix_newlines_in_conf();
 
     /* Populate the server settings */    
     populate_server_settings(widgets);
