@@ -1,25 +1,23 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
 
-
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -40,10 +38,10 @@ extern char global_share_name[1024];
 extern int activated;
 
 
+/* Changes the selected share configuration by removing
+   the old old share and adding a new one via add_share.c */
 void apply_share_settings(struct w *widgets)
 {
-    /* Changes the selected shares configuration. */
-
     FILE *fp;
     char *line, *new_conf;
     long conf_size;
@@ -67,7 +65,6 @@ void apply_share_settings(struct w *widgets)
 	return;
     }
 
-
     /* First delete the old share definition */
     if((fp=fopen(SAMBA_CONF, "r"))==NULL)
     {
@@ -114,13 +111,12 @@ void apply_share_settings(struct w *widgets)
     free(line);
     g_free(share_name);
 
-//    if( ! found_share )
-//    {
-//       Tell the user.... strcat(global_share_name, "");
-//       free(new_conf);
+    if( ! found_share )
+    {
+       free(new_conf);
 //       ...
-// 	 return;
-//    }
+ 	 return;
+    }
 
     if((fp=fopen(SAMBA_CONF, "w+"))==NULL)
     {
@@ -132,11 +128,9 @@ void apply_share_settings(struct w *widgets)
     fclose(fp);
     free(new_conf);
 
-
     /* Add the new share definition */
     add_share(widgets);
 
-
     /* Reread the conf */
     reread_conf(widgets);
 }
