@@ -1,19 +1,19 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
@@ -65,7 +65,7 @@ void create_server_settings(struct w *widgets)
 
     /* The servers hostname */
     widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The servers host name: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: samba2 or the output of: hostname"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: Samba24. Use this name to connect to this server from the clients"), NULL);
     /* Insert the apply button */
     gtk_table_attach(GTK_TABLE(widgets->srv_set_table), apply_server_button, 2, 3, a, b, GTK_FILL|GTK_EXPAND, GTK_FILL|GTK_EXPAND, 20, 2);
     a++; b++; ent++;
@@ -77,7 +77,7 @@ void create_server_settings(struct w *widgets)
 
     /* Workgroup or domain name */
     widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Workgroup or domain name: "), 0,1,a,b,entry_size);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: work-group-name or sambaserver2.example.org (spaces arent allowed). Use this domain name to connect to from the clients"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("IE: work-group-name or sambaserver2.example.org (spaces arent allowed). If SAMBA is set up as a domain then use this domain name to connect to from the clients"), NULL);
     a++; b++; ent++;;
 
     /* Security level combo */
@@ -150,6 +150,14 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
+    /* The options above are the only options simple sharing requires */
+    make_3columns_hseparator(GTK_TABLE(widgets->srv_set_table), 0, 1, a, b);
+    a++; b++;
+    make_3columns_label(GTK_TABLE(widgets->srv_set_table),
+    _("Server settings for advanced administrators:"), 0, 1, a, b);
+    a++; b++;
+
+
 // printing = cups Not included.
 
     /* CUPS Options */
@@ -157,9 +165,9 @@ void create_server_settings(struct w *widgets)
     combo_text = g_strdup_printf(_("Raw"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("fixme...."));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
+//    combo_text = g_strdup_printf(_("fixme...."));
+//    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
+//    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
@@ -349,8 +357,6 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* Skipped all but one case directive. */
-
     /* Case sensitive filenames */
     widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Case sensitive filenames: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("Yes"));
@@ -624,7 +630,7 @@ void create_server_settings(struct w *widgets)
 
     /* Template shell */
     widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Template shell: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The template shell, IE: /bin/false"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The template shell, IE: /dev/null"), NULL);
     a++; b++; ent++;
 
 
@@ -642,7 +648,7 @@ void create_server_settings(struct w *widgets)
 
     /* Winbind separator */
     widgets->server_set_entry[ent] = make_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Winbind separator: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Winbind separator, IE: @"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Winbind separator, IE: @ for user@server.org"), NULL);
     a++; b++; ent++;
 
     /* Winbind cache time */
