@@ -1,25 +1,24 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
 
 
-
 #include "../config.h"
 #include <gtk/gtk.h>
 #include "support.h"
@@ -273,10 +272,10 @@ smbuser_exists(G_CONST_RETURN gchar *username)
 {
     /* Checks if the system user exists */
     FILE *fp;
+    char *line;
     long conf_size;
     int x, user_exists = 0;
     char tempname[4096]="";
-    char *check_buffer;
 
     /* Checks if the user exists in passwd */
     if((fp=fopen(SAMBA_PASSWD,"r"))==NULL)
@@ -288,17 +287,16 @@ smbuser_exists(G_CONST_RETURN gchar *username)
 	    fseek(fp, 0, SEEK_END);
 	    conf_size = ftell(fp);
 	    rewind(fp);
-
-	    check_buffer = allocate(conf_size);
+	    line = allocate(conf_size);
 
 	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		for(x=0; check_buffer[x]; x++)
+		for(x=0; line[x]; x++)
 		{
-		    if(check_buffer[x]==':')
+		    if( line[x]==':' )
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
 			if( ! strcmp(username, tempname) )
 			{
@@ -306,17 +304,14 @@ smbuser_exists(G_CONST_RETURN gchar *username)
 			    break;
 			}
 		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		      break;
 		}
 		if( user_exists )
 		  break;
 	    }
-	    free(check_buffer);
+	    free(line);
 	    fclose(fp);
       }
 
-
     return user_exists;
 }
 
@@ -325,12 +320,13 @@ int
 smbuser_locked(G_CONST_RETURN gchar *username)
 {
     /* Checks if the samba user is locked */
+    /* Return values: 0="Not locked" 1="Locked" 2="NULL password" */
     FILE *fp;
+    char *line;
     long conf_size;
     int x, user_exists = 0;
     int prop_found = 0, account_locked = 0;
     char tempname[4096]="";
-    char *check_buffer;
 
     if((fp=fopen(SAMBA_PASSWD,"r"))==NULL)
     {
@@ -341,17 +337,16 @@ smbuser_locked(G_CONST_RETURN gchar *username)
 	    fseek(fp, 0, SEEK_END);
 	    conf_size = ftell(fp);
 	    rewind(fp);
-
-	    check_buffer = allocate(conf_size);
+	    line = allocate(conf_size+1);
 
 	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		for(x=0; check_buffer[x]; x++)
+		for(x=0; line[x]!='\0'; x++)
 		{
-		    if(check_buffer[x]==':')
+		    if( line[x]==':' )
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
 			if( ! strcmp(username, tempname) )
 			{
@@ -359,20 +354,17 @@ smbuser_locked(G_CONST_RETURN gchar *username)
 			    break;
 			}
 		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		      break;
 		}
 		if( user_exists )
 		  break;
 	    }
 
-	    
 	    /* The samba user exists, see if its locked */
 	    if( user_exists )
-	    for(x=0; check_buffer[x]; x++)
+	    for(x=0; line[x]!='\0'; x++)
 	    {
 		/* Account properties are located between "[" and "]" */
-		if( check_buffer[x]=='[' )
+		if( line[x]=='[' )
 		{
 		    prop_found = 1;
 		    break;
@@ -380,20 +372,26 @@ smbuser_locked(G_CONST_RETURN gchar *username)
 	    }
 	    
 	    if( user_exists && prop_found )
-	    for(x=x; check_buffer[x]; x++)
+	    for(x=x; line[x]!='\0'; x++)
 	    {
-		/* Read to account properties end "]" */
-		if( check_buffer[x]==']' )
-		  break;
-		
-		if( check_buffer[x]=='D' )
-		{
-		    account_locked = 1;
+		/* Read to the end of account properties "]" */
+		if( line[x]==']' )
 		    break;
-		}
+
+		/* Disabled accounts with previously set passwords
+		   can be enabled without setting a new one */
+		if( line[x]=='D' && ! strstr(line, "XXXXXXXXXXXX") )
+		    account_locked = 1;
+
+		/* Enabling accounts with no previous passwords requires new passwords */
+		if( line[x]=='D' && strstr(line, "XXXXXXXXXXXX") )
+		    account_locked = 2;
+
+		/* Enabling accounts with NULL passwords requires new passwords */
+		if( line[x]=='N' )
+		    account_locked = 3;
 	    }
-	    
-	    free(check_buffer);
+	    free(line);
 	    fclose(fp);
       }
 
@@ -401,16 +399,15 @@ smbuser_locked(G_CONST_RETURN gchar *username)
 }
 
 
-
 int
 user_exists(G_CONST_RETURN gchar *username)
 {
     /* Checks if the system user exists */
     FILE *fp;
+    char *line;
     long conf_size;
     int x, user_exists = 0;
     char tempname[4096]="";
-    char *check_buffer;
 
     /* Checks if the user exists in passwd */
     if((fp=fopen(PASSWD_FILE,"r"))==NULL)
@@ -422,17 +419,16 @@ user_exists(G_CONST_RETURN gchar *username)
 	    fseek(fp, 0, SEEK_END);
 	    conf_size = ftell(fp);
 	    rewind(fp);
-
-	    check_buffer = allocate(conf_size);
+	    line = allocate(conf_size);
 
 	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		for(x=0; check_buffer[x]; x++)
+		for(x=0; line[x]; x++)
 		{
-		    if(check_buffer[x]==':')
+		    if( line[x]==':' )
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
 			if( ! strcmp(username, tempname) )
 			{
@@ -440,16 +436,14 @@ user_exists(G_CONST_RETURN gchar *username)
 			    break;
 			}
 		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		    break;
 		}
+		if( user_exists )
+		    break;
 	    }
-	    free(check_buffer);
+	    free(line);
+	    fclose(fp);
       }
 
-    fclose(fp);
-
-
     /* Checks if the user exists in shadow */
     if((fp=fopen(SHADOW_FILE,"r"))==NULL)
     {
@@ -460,17 +454,16 @@ user_exists(G_CONST_RETURN gchar *username)
 	    fseek(fp, 0, SEEK_END);
 	    conf_size = ftell(fp);
 	    rewind(fp);
-
-	    check_buffer = allocate(conf_size);
+	    line = allocate(conf_size);
 
 	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		for(x=0; check_buffer[x]; x++)
+		for(x=0; line[x]!='\0'; x++)
 		{
-		    if(check_buffer[x]==':')
+		    if( line[x]==':' )
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
 			if( strstr(username, tempname) 
 			&& strlen(username) == strlen(tempname) )
@@ -479,11 +472,11 @@ user_exists(G_CONST_RETURN gchar *username)
 			    break;
 			}
 		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		    break;
+		    if( user_exists )
+			break;
 		}
 	    }
-	    free(check_buffer);
+	    free(line);
 	    fclose(fp);
       }
 
@@ -496,10 +489,10 @@ group_exists(G_CONST_RETURN gchar *groupname)
 {
     /* Checks if the system group already exists */
     FILE *fp;
+    char *line;
     long conf_size;
-    int x, group_exists=0;
+    int x, group_exists = 0;
     char tempname[4096]="";
-    char *check_buffer;
 
     /* Checks if the group exists in group */
     if((fp=fopen(GROUP_FILE,"r"))==NULL)
@@ -511,16 +504,16 @@ group_exists(G_CONST_RETURN gchar *groupname)
 	    fseek(fp, 0, SEEK_END);
 	    conf_size = ftell(fp);
 	    rewind(fp);
-	    check_buffer = allocate(conf_size);
+	    line = allocate(conf_size);
 
 	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		for(x=0; check_buffer[x]; x++)
+		for(x=0; line[x]!='\0'; x++)
 		{
-		    if(check_buffer[x]==':')
+		    if( line[x]==':' )
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
 			if( ! strcmp(groupname, tempname) )
 			{
@@ -528,11 +521,11 @@ group_exists(G_CONST_RETURN gchar *groupname)
 			    break;
 			}
 		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		    break;
 		}
+		if( group_exists )
+		    break;
 	    }
-	    free(check_buffer);
+	    free(line);
 	    fclose(fp);
       }
 
@@ -546,30 +539,32 @@ group_exists(G_CONST_RETURN gchar *groupname)
 	    fseek(fp, 0, SEEK_END);
 	    conf_size = ftell(fp);
 	    rewind(fp);
-	    check_buffer = allocate(conf_size);
+	    line = allocate(conf_size);
 	    
 	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		for(x=0; check_buffer[x]; x++)
+		for(x=0; line[x]!='\0'; x++)
 		{
-		    if(check_buffer[x]==':')
+		    if( line[x]==':' )
 		    {
-			sprintf(tempname, check_buffer);
+			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
-			if( strstr(groupname, tempname) && strlen(groupname)==strlen(tempname) )
+			if( strstr(groupname, tempname) 
+			&& strlen(groupname) == strlen(tempname) )
 			{
 			    group_exists = 1;
 			    break;
 			}
 		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		    break;
 		}
+		if( group_exists )
+		    break;
 	    }
-	    free(check_buffer);
+	    free(line);
 	    fclose(fp);
       }
+
     return group_exists;
 }
 
@@ -585,7 +580,6 @@ gchar *get_group_name(gchar *groupnr)
     gchar *retval = NULL;
     gint val_pos = 0;
 
-
     /* position of the group number (name is always first) */
     val_pos = 2;
 
@@ -680,10 +674,10 @@ gchar *get_user_setting(gchar *user, gchar *what)
 {
     /* Gets the users comment from passwd */
     FILE *fp;
+    char *line;
     long conf_size;
     int x=0, y=0, found_user=0, found_val=0, count=0;
     char *tempname;
-    char *check_buffer;
     gchar *retval = NULL;
     gint val_pos = 0;
 
@@ -713,17 +707,16 @@ gchar *get_user_setting(gchar *user, gchar *what)
 	    fseek(fp, 0, SEEK_END);
 	    conf_size = ftell(fp);
 	    rewind(fp);
-
-	    check_buffer = allocate(conf_size);
+	    line = allocate(conf_size);
 
 	    if( conf_size > 1 )
-	    while(fgets(check_buffer, conf_size, fp)!=NULL)
+	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		for(x=0; check_buffer[x]; x++)
+		for(x=0; line[x]!='\0'; x++)
 		{
-		    if(check_buffer[x]==':')
+		    if( line[x]==':' )
 		    {
-			snprintf(tempname, 4000, "%s", check_buffer);
+			snprintf(tempname, 4000, "%s", line);
 			tempname[x]='\0';
 			if( ! strcmp(user, tempname) )
 			{
@@ -731,8 +724,6 @@ gchar *get_user_setting(gchar *user, gchar *what)
 			    break;
 			}
 		    }
-		    if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-		      break;
 		}
 		if( found_user )
 		  break;
@@ -744,25 +735,21 @@ gchar *get_user_setting(gchar *user, gchar *what)
 
     /* If the user is found, get the specified section */
     if( found_user )
-    for(x=0; check_buffer[x]; x++)
+    for(x=0; line[x]!='\0'; x++)
     {
-	if( check_buffer[x]=='\0' || check_buffer[x]=='\n' )
-	  break;
-
-	if(check_buffer[x]==':')
+	if( line[x]==':' )
 	{
 	    count++;
 	    /* The val_pos colon is found, beginning of the value to get */
 	    if( count == val_pos )
 	    {
-		snprintf(tempname, 4000, "%s", &check_buffer[x+1]);
+		snprintf(tempname, 4000, "%s", &line[x+1]);
 		break;
 	    }
 	}
     }
 
-    free(check_buffer);
-
+    free(line);
 
     /* Snip at value end, shell comes last and should be newline terminated */
     if( found_user )
@@ -802,13 +789,7 @@ password_user(G_CONST_RETURN gchar *username, G_CONST_RETURN gchar *password)
     char *user_pass, *encrypted_pass;
 
     if( ! user_exists(username) )
-    {
-//	sprintf(info_buffer, _("User: %s could not be found in passwd or shadow.\n"), username);
-//	strcat(info_buffer, _("The password was not changed.\n"));
-//    	info_window=create_info_window();
-//    	gtk_widget_show(info_window);
-	return;
-    }
+      return;
 
     user_pass = allocate(8192);
 
@@ -821,19 +802,19 @@ password_user(G_CONST_RETURN gchar *username, G_CONST_RETURN gchar *password)
 	printf("Crypt error: using the chpass(wd) program instead\n");
 
 #if defined USE_LINUX
-	sprintf(user_pass, "echo %s:%s | chpasswd", username, password);
+	snprintf(user_pass, 8000, "echo %s:%s | chpasswd", username, password);
 #endif
 
 
 #if defined USE_OPENBSD || USE_NETBSD || USE_FREEBSD
-	sprintf(user_pass, "echo %s:%s | chpass", username, password);
+	snprintf(user_pass, 8000, "echo %s:%s | chpass", username, password);
 #endif
 
 
 #if defined USE_DARWIN
 	/* Someone who knows what can be used .. niutil lines ? */
 	printf("Darwin functions are defined in osx_functions, this is a bug\n");
-	sprintf(user_pass, "echo passwd/username %s:%s", username, password);
+	snprintf(user_pass, 8000, "echo passwd/username %s:%s", username, password);
 #endif
 
     }
@@ -842,28 +823,26 @@ password_user(G_CONST_RETURN gchar *username, G_CONST_RETURN gchar *password)
 	/* Using encrypted passwords */
 
 #if defined USE_LINUX
-	sprintf(user_pass, "usermod -p '%s' %s", encrypted_pass, username);
+	snprintf(user_pass, 8000, "usermod -p '%s' %s", encrypted_pass, username);
 #endif
 
 #if defined USE_OPENSBD || USE_NETBSD || USE_FREEBSD || USE_AIX || USE_HPUX
-	sprintf(user_pass, "pw usermod -p '%s' %s", encrypted_pass, username);
+	snprintf(user_pass, 8000, "pw usermod -p '%s' %s", encrypted_pass, username);
 #endif
 
 #if defined USE_DARWIN
-	sprintf(user_pass, "echo manually change the password: passwd/username '%s' %s", encrypted_pass, username);
+	snprintf(user_pass, 8000, "echo \"manually change the password: passwd/username '%s' %s\"", encrypted_pass, username);
 #endif
 
       }	
 
-
     /* Now we have the correct password changing string, change it */
-
     if((fp=popen(user_pass,"w"))==NULL)
     {
         perror("popen");
-//	sprintf(info_buffer, _("Error changing password for user: %s\n"), username);
-//    	info_window=create_info_window();
-//    	gtk_widget_show(info_window);
+//	info = g_strdup_printf(_("Error changing password for user: %s\n"), username);
+//    	show_info(info);
+//	g_free(info);
     }
     else
       pclose(fp);
@@ -878,7 +857,6 @@ password_user(G_CONST_RETURN gchar *username, G_CONST_RETURN gchar *password)
 
 
 
-
 char *encrypt_password(G_CONST_RETURN gchar *password)
 {
     /* Make an encrypted password using the MD5 algoritm */
@@ -946,18 +924,18 @@ void make_file_chmod(gchar *file, char perm[128])
 int
 fix_newlines_in_conf()
 {
-    /* Strip all newlines between directives */
-    /* * then add newlines before <Anonymous and <VirtualHost */
+    /* Strip all newlines between directives.
+       Add newlines before any share "[" "]" */
     FILE *fp;
     char *old_buffer, *new_buffer;
     long conf_size, allocate_extra=0;
 
-    /* First remove any newlines first on all lines in the config */
-    /* And see how many new chars we will be adding */
+    /* First remove any newlines first on all lines in the config.
+       Check how many new chars we will be adding */
     if((fp=fopen(SAMBA_CONF, "r"))==NULL)
     {
-       printf("Error reading %s for adding newlines\n", SAMBA_CONF);
-       return 0;
+        printf("Error reading samba configuration: %s\n", SAMBA_CONF);
+        return 0;
     }
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
@@ -976,7 +954,7 @@ fix_newlines_in_conf()
 	else
 	  strcat(new_buffer, old_buffer);	  	  
 
-	if( strstr(old_buffer, "<Anonymous") || strstr(old_buffer, "<VirtualHost") )
+	if( strstr(old_buffer, "[") && strstr(old_buffer, "]") )
 	  allocate_extra++;
     }
     fclose(fp);
@@ -986,7 +964,7 @@ fix_newlines_in_conf()
     /* Write the newline stripped conf */
     if((fp=fopen(SAMBA_CONF, "w+"))==NULL)
     {
-       printf("Error reading %s for adding newlines\n", SAMBA_CONF);
+       printf("Error writing newline stripped configuration: %s\n", SAMBA_CONF);
        free(new_buffer);
        return 0;
     }
@@ -997,7 +975,7 @@ fix_newlines_in_conf()
     /* Add the newlines */
     if((fp=fopen(SAMBA_CONF, "r"))==NULL)
     {
-       printf("Error reading %s for adding newlines\n", SAMBA_CONF);
+       printf("Error reading newline stipped configuration: %s\n", SAMBA_CONF);
        return 0;
     }
     fseek(fp, 0, SEEK_END);
@@ -1010,7 +988,7 @@ fix_newlines_in_conf()
     if( conf_size > 1 )
     while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
-	if( strstr(old_buffer, "<Anonymous") || strstr(old_buffer, "<VirtualHost") )
+	if( strstr(old_buffer, "[") && strstr(old_buffer, "]") )
 	{
 	    strcat(new_buffer, "\n");
 	    strcat(new_buffer, old_buffer);
@@ -1024,7 +1002,7 @@ fix_newlines_in_conf()
     /* Write the newline added conf */
     if((fp=fopen(SAMBA_CONF, "w+"))==NULL)
     {
-       printf("Error writing file: %s\n", SAMBA_CONF);
+       printf("Error writing newline added configuration: %s\n", SAMBA_CONF);
        free(new_buffer);
        return 0;
     }
@@ -1308,9 +1286,6 @@ char *random_string(int len)
 }
 
 
-
-
-
 /* Unused */
 void
 exec_ssl(char *command, char descr[128])
