@@ -1,19 +1,19 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
@@ -36,8 +36,7 @@
 #include "commented.h"
 #include "get_option_pos.h"
 
-extern char global_share_name[16384];
-
+extern char global_share_name[1024];
 
 
 void populate_share_settings(struct w *widgets)
@@ -45,18 +44,24 @@ void populate_share_settings(struct w *widgets)
     /* Lists all share settings */
     FILE *fp;
     char *line, *shareopt;
-    long conf_size, opt_pos;
+    long conf_size, opt_pos, x;
     int i, found_share = 0;
+    GtkTreeIter iter;
     gchar *utf8 = NULL;
 
     /* Clear all share entries */
-    for(i=0; i<10; i++) 
+    for(i=0; i<7; i++) 
       gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[i]), "");
 
     /* Set all share combos to the most restrictive setting ("off", "no", etc) */
     for(i=0; i<9; i++)
       gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->share_set_combo[i]), 1);
 
+    /* Clear the user access treeviews */
+    gtk_list_store_clear(widgets->valid_users_store);
+    gtk_list_store_clear(widgets->invalid_users_store);
+    gtk_list_store_clear(widgets->write_users_store);
+    gtk_list_store_clear(widgets->admin_users_store);
 
     /* Populate the share settings */
     if((fp=fopen(SAMBA_CONF, "r"))==NULL)
@@ -116,7 +121,7 @@ void populate_share_settings(struct w *widgets)
 		    gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[1]), utf8);
 		}
 
-		/* comment */
+		/* Comment */
 		if( cmplowercase(line, "comment") )
 		{
 		    opt_pos = get_option_pos(line);
@@ -126,7 +131,119 @@ void populate_share_settings(struct w *widgets)
 		}
 
 		/* Valid users */
-		if( cmplowercase(line, "valid users") )
+		if( cmplowercase(line, "valid users") && ! cmplowercase(line,"invalid users") )
+		{
+		    i=0; x=0;
+		    opt_pos = get_option_pos(line);
+		    for(i=opt_pos-1; line[i]!='\0'; i++)
+		    {
+			if( line[i-1]==' ' && line[i]!=' ' )
+			for(x=i; line[x]!='\0'; x++)
+			{
+			    if( line[x]!=' ' && (line[x+1]==' ' || line[x+1]=='\0') )
+			    {
+		    	        snprintf(shareopt, (x+2)-i, "%s", &line[i]);
+		    	        if( shareopt[strlen(shareopt)-1]=='\n' )
+		    	          shareopt[strlen(shareopt)-1]='\0';
+
+		    	        if( strlen(shareopt) > 0 && i > opt_pos-1 )
+		    	        {
+				    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt), NULL, NULL, NULL);
+		    	    	    gtk_list_store_append(GTK_LIST_STORE(widgets->valid_users_store), &iter);
+	            	    	    gtk_list_store_set(GTK_LIST_STORE(widgets->valid_users_store), &iter, 0, utf8, -1);
+	            	    	}
+	            	        break;
+			    }
+			}
+		    }
+		}
+
+		/* Invalid users */
+		if( cmplowercase(line, "invalid users") )
+		{
+		    i=0; x=0;
+		    opt_pos = get_option_pos(line);
+		    for(i=opt_pos-1; line[i]!='\0'; i++)
+		    {
+			if( line[i-1]==' ' && line[i]!=' ' )
+			for(x=i; line[x]!='\0'; x++)
+			{
+			    if( line[x]!=' ' && (line[x+1]==' ' || line[x+1]=='\0') )
+			    {
+		    	        snprintf(shareopt, (x+2)-i, "%s", &line[i]);
+		    	        if( shareopt[strlen(shareopt)-1]=='\n' )
+		    	          shareopt[strlen(shareopt)-1]='\0';
+		    	        
+		    	        if( strlen(shareopt) > 0 && i > opt_pos-1 )
+		    	        {
+				    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt), NULL, NULL, NULL);
+		    	    	    gtk_list_store_append(GTK_LIST_STORE(widgets->invalid_users_store), &iter);
+	            	    	    gtk_list_store_set(GTK_LIST_STORE(widgets->invalid_users_store), &iter, 0, utf8, -1);
+	            	    	}
+	            	    	break;
+			    }
+			}
+		    }
+		}
+
+		/* Write list */
+		if( cmplowercase(line, "write list") )
+		{
+		    i=0; x=0;
+		    opt_pos = get_option_pos(line);
+		    for(i=opt_pos-1; line[i]!='\0'; i++)
+		    {
+			if( line[i-1]==' ' && line[i]!=' ' )
+			for(x=i; line[x]!='\0'; x++)
+			{
+			    if( line[x]!=' ' && (line[x+1]==' ' || line[x+1]=='\0') )
+			    {
+		    	        snprintf(shareopt, (x+2)-i, "%s", &line[i]);
+		    	        if( shareopt[strlen(shareopt)-1]=='\n' )
+		    	          shareopt[strlen(shareopt)-1]='\0';
+
+		    	        if( strlen(shareopt) > 0 && i > opt_pos-1 )
+		    	        {
+				    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt), NULL, NULL, NULL);
+		    	    	    gtk_list_store_append(GTK_LIST_STORE(widgets->write_users_store), &iter);
+	            	    	    gtk_list_store_set(GTK_LIST_STORE(widgets->write_users_store), &iter, 0, utf8, -1);
+	            	    	}
+	            	        break;
+			    }
+			}
+		    }
+		}
+
+		/* Admin users */
+		if( cmplowercase(line, "admin users") )
+		{
+		    i=0; x=0;
+		    opt_pos = get_option_pos(line);
+		    for(i=opt_pos-1; line[i]!='\0'; i++)
+		    {
+			if( line[i-1]==' ' && line[i]!=' ' )
+			for(x=i; line[x]!='\0'; x++)
+			{
+			    if( line[x]!=' ' && (line[x+1]==' ' || line[x+1]=='\0') )
+			    {
+		    	        snprintf(shareopt, (x+2)-i, "%s", &line[i]);
+		    	        if( shareopt[strlen(shareopt)-1]=='\n' )
+		    	          shareopt[strlen(shareopt)-1]='\0';
+
+		    	        if( strlen(shareopt) > 0 && i > opt_pos-1 )
+		    	        {
+				    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt), NULL, NULL, NULL);
+		    	    	    gtk_list_store_append(GTK_LIST_STORE(widgets->admin_users_store), &iter);
+	            	    	    gtk_list_store_set(GTK_LIST_STORE(widgets->admin_users_store), &iter, 0, utf8, -1);
+	            	    	}
+	            	        break;
+			    }
+			}
+		    }
+		}
+
+		/* Directory mask */
+		if( cmplowercase(line, "directory mask") )
 		{
 		    opt_pos = get_option_pos(line);
 		    snprintf(shareopt, conf_size, "%s", &line[opt_pos]);
@@ -134,42 +251,14 @@ void populate_share_settings(struct w *widgets)
 		    gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[3]), utf8);
 		}
 		
-		/* Write list */
-		if( cmplowercase(line, "write list") )
+		/* Create mode */
+		if( cmplowercase(line, "create mode") )
 		{
 		    opt_pos = get_option_pos(line);
 		    snprintf(shareopt, conf_size, "%s", &line[opt_pos]);
     		    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt)-1, NULL, NULL, NULL);
 		    gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[4]), utf8);
 		}
-		
-		/* Admin users */
-		if( cmplowercase(line, "admin users") )
-		{
-		    opt_pos = get_option_pos(line);
-		    snprintf(shareopt, conf_size, "%s", &line[opt_pos]);
-    		    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt)-1, NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[5]), utf8);
-		}
-
-		/* directory mask */
-		if( cmplowercase(line, "directory mask") )
-		{
-		    opt_pos = get_option_pos(line);
-		    snprintf(shareopt, conf_size, "%s", &line[opt_pos]);
-    		    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt)-1, NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[6]), utf8);
-		}
-		
-		/* create mode */
-		if( cmplowercase(line, "create mode") )
-		{
-		    opt_pos = get_option_pos(line);
-		    snprintf(shareopt, conf_size, "%s", &line[opt_pos]);
-    		    utf8 = g_locale_to_utf8(shareopt, strlen(shareopt)-1, NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->share_set_entry[7]), utf8);
-		}
-
 
 
 
@@ -286,10 +375,8 @@ void populate_share_settings(struct w *widgets)
     if( utf8 !=NULL )
       g_free(utf8);
 
-//    if( ! found_share ) .. its most likely found but fix later
+//    if( ! found_share ) .. Fix later
 //    {
-//	  Tell the user.... sprintf(global_share_name, "");
-//        ...
 //        return;
 //    }
 }
