@@ -1,23 +1,24 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
 
+
 #include "../config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -38,12 +39,10 @@ extern char global_user_name[1024];
 
 void populate_user_settings(struct w *widgets)
 {
-    gchar *info;
-    gchar *utf8=NULL;
-    int i=0;
+    gchar *info, *utf8, *atext;
+    int i=0, locked = 0;
     gchar *what, *val;
 
-
     info = g_strdup_printf("%s", global_user_name);
     if( info == NULL || strlen(info) < 1 )
     {
@@ -58,15 +57,49 @@ void populate_user_settings(struct w *widgets)
     gchar *username = g_strdup_printf("%s", global_user_name);
     gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[0]), username);
 
-    /* Locked account checkbox */
-    if( smbuser_locked(username) )
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), TRUE);
+    /* Locked account checkbox and label modifications */
+    locked = smbuser_locked(username);
+    
+    if( locked && ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0])) )
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), TRUE);
+    if( ! locked && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0])) )
+        gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), FALSE);
+
+    if( locked == 1 || locked == 2 )
+    {
+	/* Regular samba user account is locked */
+	atext = g_strdup_printf(_("Account locked:"));
+	utf8 = g_locale_to_utf8(atext, strlen(atext), NULL, NULL, NULL);
+	gtk_label_set_text(GTK_LABEL(widgets->acclock_label), utf8);
+	if( atext!=NULL )
+	  g_free(atext);
+	if( utf8!=NULL )
+	  g_free(utf8);
+    }
     else
-      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->user_set_checkbutton[0]), FALSE);
-
-
-    /* Dont insert the password */
-
+    if( locked == 3 )
+    {
+	/* A samba user with a Null password is considered locked but
+	   show that it has an  empty password */
+	atext = g_strdup_printf(_("Empty password:"));
+	utf8 = g_locale_to_utf8(atext, strlen(atext), NULL, NULL, NULL);
+	gtk_label_set_text(GTK_LABEL(widgets->acclock_label), utf8);
+	if( atext!=NULL )
+	  g_free(atext);
+	if( utf8!=NULL )
+	  g_free(utf8);
+    }
+    else
+    {
+	/* Regular samba user is not locked (locked == 0 ) */
+	atext = g_strdup_printf(_("Account locked:"));
+	utf8 = g_locale_to_utf8(atext, strlen(atext), NULL, NULL, NULL);
+	gtk_label_set_text(GTK_LABEL(widgets->acclock_label), utf8);
+	if( atext!=NULL )
+	  g_free(atext);
+	if( utf8!=NULL )
+	  g_free(utf8);
+    }
 
     what = g_strdup_printf("group");
     val = get_user_setting(username, what);
@@ -75,27 +108,24 @@ void populate_user_settings(struct w *widgets)
     g_free(what); g_free(val);
     g_free(groupname);
 
-
     what = g_strdup_printf("comment");
     val = get_user_setting(username, what);
     gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[3]), val);
     g_free(what); g_free(val);
 
-
     what = g_strdup_printf("homedir");
     val = get_user_setting(username, what);
     gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), val);
     g_free(what); g_free(val);
 
-
     what = g_strdup_printf("shell");
     val = get_user_setting(username, what);
-    g_free(what);
+    g_free(what); g_free(username);
 
     /* Select the shell we just got in the shell combo box */
     GtkListStore *shell_store;
     shell_store = GTK_LIST_STORE (gtk_combo_box_get_model(GTK_COMBO_BOX(widgets->user_set_combo[0])));
-	              
+
     if( shell_store )
     {
         GtkTreeIter shell_iter;
@@ -113,14 +143,11 @@ void populate_user_settings(struct w *widgets)
                             break;
                         }
                     }
+                    if( shell!=NULL )
+                      g_free(shell);
                
 	       }    while(gtk_tree_model_iter_next(GTK_TREE_MODEL(shell_store), &shell_iter));
         }
     }
-
     g_free(val);
-    g_free(username); 
-    
-    if( utf8!=NULL )
-      g_free(utf8);
 }
