@@ -1,19 +1,19 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
@@ -30,6 +30,7 @@
 #include "allocate.h"
 #include "save_settings.h"
 #include "load_settings.h"
+#include "standard_conf.h"
 
 
 
@@ -120,10 +121,9 @@ void save_settings(struct w *widgets)
     /* Load the new settings */
     load_settings(widgets);
 
-    /* Reread the entire gui */
-//    populate_domain_treeview(widgets);
-//    populate_resource_treeview(widgets);
-//    populate_resolvers(widgets);
-//    populate_root_servers_tab(widgets);
-//    populate_log_tab(widgets);
+    /* If new configuration is selected, show standard conf question */
+    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->settings_checkbutton[0])) )
+    {
+	create_standard_conf_question(widgets);
+    }
 }
