@@ -1,19 +1,19 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
@@ -32,6 +32,7 @@
 #include "make_settings_combos.h"
 #include "make_settings_checkbuttons.h"
 #include "reread_conf.h"
+#include "load_settings.h"
 #include "save_settings.h"
 #include "settings_window.h"
 
@@ -39,13 +40,6 @@
 
 extern int global_start_winbindd;
 
-//extern char global_domain_name[1024];
-//extern char global_domain_address[1024];
-//extern char global_domain_type[1024];
-
-//extern char SYSLOG_PATH_BUF[1024];
-//extern char RESOLV_PATH_BUF[1024];
-//extern char CHROOT_PATH_BUF[1024];
 
 
 void show_settings_window(struct w *widgets)
@@ -85,8 +79,8 @@ void show_settings_window(struct w *widgets)
 
     /* Max length and input 350 chars */
 
-    /* Show conf question */
-    widgets->settings_checkbutton[0] = make_checkbutton_with_label(GTK_TABLE(table), _(" Default configuration: "), 0,1,1,2);
+    /* Show standard conf question */
+    widgets->settings_checkbutton[0] = make_checkbutton_with_label(GTK_TABLE(table), _(" New configuration: "), 0,1,1,2);
 
     /* Start winbindd checkbutton */
     widgets->settings_checkbutton[1] = make_checkbutton_with_label(GTK_TABLE(table), _(" Start winbindd: "), 0,1,2,3);
@@ -128,14 +122,12 @@ void show_settings_window(struct w *widgets)
 }
 
 
-
 void cancel_settings_button_clicked(struct w *widgets)
 {
     gtk_widget_destroy(widgets->settings_window);
 }
 
 
-
 void apply_settings_button_clicked(struct w *widgets)
 {
     /* The apply button in the settings window */
@@ -144,12 +136,5 @@ void apply_settings_button_clicked(struct w *widgets)
 
     load_settings(widgets);
 
-    /* Repopulate the gui */
-//    populate_domain_treeview(widgets);
-
-//    populate_resource_treeview(widgets);
-
-//    populate_log_tab(widgets);
-    
     gtk_widget_destroy(widgets->settings_window);
 }
