@@ -1,23 +1,24 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
 
+
 #include "../config.h"
 #include <gtk/gtk.h>
 #include "gettext.h"
@@ -114,6 +115,30 @@ int conf_ok(gchar *file_path)
 }
 
 
+void backup_samba_conf(struct w *widgets)
+{
+    gchar *cmd, *info;
+
+    if( ! file_exists(SAMBA_CONF_BACKUP) && file_exists(SAMBA_CONF) )
+    {
+	cmd = g_strdup_printf("cp %s %s", SAMBA_CONF, SAMBA_CONF_BACKUP);
+	if( ! run_command(cmd) )
+	{
+	    info = g_strdup_printf(_("Error: Could not backup the current configuration:\n%s\n"), SAMBA_CONF);
+	    show_info(info);
+	}
+	else
+	  {
+	     info = g_strdup_printf(_("The samba configuration was backed up here for safety:\n%s\n"), SAMBA_CONF_BACKUP);
+	     show_info(info);
+	  }
+
+	g_free(cmd);
+	g_free(info);
+    }
+}
+
+
 void add_standard_conf(struct w *widgets)
 {
     /* This backs up the old configuration and adds the default configuration */
@@ -122,25 +147,9 @@ void add_standard_conf(struct w *widgets)
     gchar *cmd, *info;
 
     /* First take a backup of the old configuration as SAMBA_CONF_BACKUP if it doesnt exist */
-    if( ! file_exists(SAMBA_CONF_BACKUP) && file_exists(SAMBA_CONF) )
-    {
-	cmd = g_strdup_printf("cp %s %s", SAMBA_CONF, SAMBA_CONF_BACKUP);
-	if( ! run_command(cmd) )
-	{
-	    info = g_strdup_printf(_("Error: Could not backup the current configuration:\n%s\n"), SAMBA_CONF);
-	    show_info(info);
-	    g_free(cmd);
-	    return;
-	}
-	else
-	  {
-	     info = g_strdup_printf(_("The old smb.conf configuration was backed up as:\n%s\n"), SAMBA_CONF_BACKUP);
-	     show_info(info);
-	  }
-	g_free(cmd);
-    }
+    backup_samba_conf(widgets);
 
-    /* Add the default configuration */
+    /* Write the default configuration */
     if((fp=fopen(SAMBA_CONF, "w+"))==NULL)
     {
 	info = g_strdup_printf(_("Cant write a new smb.conf here:\n%s\n"), SAMBA_CONF);
@@ -196,7 +205,7 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "wins server =\n");
     strcat(buffer, "wins proxy = no\n");
     strcat(buffer, "dns proxy = no\n");
-    strcat(buffer, "preserve case = no\n");
+    strcat(buffer, "preserve case = yes\nshort preserve case = yes\n");
     strcat(buffer, "client use spnego = no\n");
     strcat(buffer, "client signing = no\n");
     strcat(buffer, "client schannel = no\n");
@@ -350,11 +359,11 @@ void add_standard_conf(struct w *widgets)
     strcat(buffer, "lpq command =\n");
     strcat(buffer, "lprm command =\n");
 
-	    
     fputs(buffer, fp);
     fclose(fp);
     free(buffer);
 
+
     if( GTK_IS_WINDOW(widgets->default_conf_question_window) )
       gtk_widget_destroy(widgets->default_conf_question_window);
 
@@ -458,7 +467,6 @@ void add_standard_conf(struct w *widgets)
 }
 
 
-
 void dont_add_standard_conf(struct w *widgets)
 {
     gtk_widget_destroy(widgets->default_conf_question_window);
@@ -485,7 +493,7 @@ void create_standard_conf_question(struct w *widgets)
     gchar *cmd, *info, *text, *utf8;
 
     widgets->default_conf_question_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_widget_set_size_request(widgets->default_conf_question_window, 500, 340);
+    gtk_widget_set_size_request(widgets->default_conf_question_window, 550, 340);
     gtk_window_set_title(GTK_WINDOW(widgets->default_conf_question_window), _("GSAMBAD Question"));
     gtk_window_set_position(GTK_WINDOW(widgets->default_conf_question_window), GTK_WIN_POS_CENTER);
 
@@ -510,7 +518,7 @@ void create_standard_conf_question(struct w *widgets)
 
 
     text = g_strconcat(
-    _("GSAMBAD could not find SAMBAs configuration smb.conf or the current\n"),
+    _("GSAMBAD could not find SAMBAs configuration (smb.conf) or the current\n"),
     _("configuration doesnt have all the features that GSAMBAD requires.\n\n"),
 
     _("Do you want to overwrite the current samba configuration ?\n"),
