@@ -1,19 +1,19 @@
 /* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
- * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006, 2007 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
 */
 
@@ -58,7 +58,6 @@ typedef struct w
   GtkWidget *notebook_vbox8;
   GtkWidget *notebook_vbox9;
   
-  GtkWidget *gsambad_version_label;
   GtkWidget *status_label;
   GtkWidget *version_label;
 
@@ -85,7 +84,7 @@ typedef struct w
   GtkWidget *user_set_combo[NUM_USERTAB_COMBOS];
   GtkWidget *gen_cert_progressbar;
   GtkWidget *usr_set_table;
-
+  GtkWidget *acclock_label;
 
   /* The add user widgets */
   GtkWidget *useradd_username_entry;
@@ -95,13 +94,10 @@ typedef struct w
   GtkWidget *useradd_comment_entry;
   GtkWidget *useradd_shell_combo;
 
-
   /* The user tab's directory treeview */
   GtkWidget *directory_treeview;
   GtkListStore *directory_store;
 
-
-
   /* The share tab's widgets */
   GtkWidget *share_treeview;
   GtkListStore *share_store;
@@ -114,51 +110,49 @@ typedef struct w
   GtkWidget *share_set_checkbutton[NUM_SHARETAB_CHECKBUTTONS];
   GtkWidget *share_set_combo[NUM_SHARETAB_COMBOS];
   GtkWidget *share_set_table;
-
-
+  /* User and group access (valid/invalid/write/admin) */
+  GtkWidget *valid_users_treeview;
+  GtkListStore *valid_users_store;
+  GtkWidget *invalid_users_treeview;
+  GtkListStore *invalid_users_store;
+  GtkWidget *write_users_treeview;
+  GtkListStore *write_users_store;
+  GtkWidget *admin_users_treeview;
+  GtkListStore *admin_users_store;
 
   /* The delete system user question window */
   GtkWidget *del_system_user_question_window;
 
   /* The add default configuration question window */
   GtkWidget *default_conf_question_window;
-  
 
   /* The machine account tab's widgets */
   GtkWidget *macct_treeview;
   GtkListStore *macct_store;
   GtkWidget *macct_settings_vbox;
   GtkWidget *macct_settings_scrolled_window;
-
   GtkWidget *macct_set_table;
   GtkWidget *macct_set_entry[NUM_MACCTTAB_ENTRIES];
 
-
   /* The connection tabs widgets */
   GtkWidget *conns_treeview;
   GtkListStore *conns_store;
 
-
   /* The disc tabs widgets */
   GtkWidget *disc_treeview;
   GtkListStore *disc_store;
 
-
   /* The file treeview */
   GtkWidget *file_treeview;
   GtkListStore *file_store;
 
-
   /* The security tabs widgets */
   GtkWidget *security_treeview;
   GtkListStore *security_store;
 
-
   /* The conf tabs textview */
   GtkWidget *conf_textview;
 
-
-
   /* The import questions widgets */
   GtkWidget *import_question_window;
 
@@ -169,31 +163,15 @@ typedef struct w
   GtkWidget *import_chkbtn_groups;
 
   GtkWidget *import_chkbtn_valid;
+  GtkWidget *import_chkbtn_invalid;
   GtkWidget *import_chkbtn_write;
   GtkWidget *import_chkbtn_admin;
 
- 
-
   /* The import selectors widgets */
   GtkWidget *import_window;
   GtkWidget *import_treeview;
   GtkListStore *import_store;
 
-  GtkWidget *import_home_entry;
-  GtkWidget *import_upload_entry;
-
-  GtkWidget *import_namebased_checkbutton;
-  GtkWidget *import_upload_checkbutton;
-  
-
-  /* The shutdown windows widgets */
-  GtkWidget *shutdown_window;
-  GtkWidget *new_acc_disabled_entry;
-  GtkWidget *existing_users_dc_entry;
-  GtkWidget *real_shutdown_entry;
-  GtkWidget *shutdown_msg_entry;
-
-
   /* The settings window */
   GtkWidget *settings_window;
   GtkWidget *settings_entry[NUM_SETTINGS_ENTRIES];
